<?php

// Photo Sidebar Widget
//
// Copyright (c) 2007 Marcel Proulx
// http://www.district30.net/smugmug-photo-sidebar/
//
// This is an add-on for WordPress
// http://wordpress.org/
//
// **********************************************************************
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// *****************************************************************

/*
Plugin Name: Photo Sidebar Widget
Plugin URI: http://www.district30.net/smugmug-photo-sidebar/
Description: Integrate photos from an RSS feed via a sidebar widget.
Author: Marcel Proulx
Version: 1.0
Author URI: http://www.district30.net
*/ 

/* Function: widget_photo_sb_init
** This function contains all of the functions we use to create the widget; this
** ensures that everything is loaded.
**
** args: none
** returns: nothing
*/

function widget_photo_sb_init() {

	if(!function_exists('register_sidebar_widget'))
		return;

	/* Function: disp_sm_feed
	** This function does the actual display of the sidebar
	**
	** args: environment variables (handled automatically by the hook)
	** returns: nothing
	*/

	function disp_sm_feed($args) {

		// Each widget can store its own options. We keep strings here.
		$options = get_option('widget_photo_sb');
		$sb_title = $options['title'];
		$feed_url = explode(", ",$options['feed_url']);
		$photo_count = $options['photo_count'];
		$draw_border = $options['draw_border'];
		$background_color = $options['background_color'];
		$padding_top = $options['padding_top'];
		$padding_right = $options['padding_right'];
		$padding_bottom = $options['padding_bottom'];
		$padding_left = $options['padding_left'];


		//get the required environment variables and begin to show the widget
		extract($args);

		echo $before_widget;
		echo $before_title
			. $sb_title
			. $after_title;

		//set up formatting to draw a border around this widget
		if ($draw_border)
			echo '<div id="photo_sb_wrapper" align="center" style="background: ' . $background_color .'; padding: ' . $padding_top . 'px ' . $padding_right . 'px ' . $padding_bottom . 'px ' . $padding_left . 'px;">';
		else
			echo '<div id="photo_sb_wrapper" align="center">';


		//Use WordPress' built-in RSS functionality
		if (!function_exists('MagpieRSS')) { // Check if another plugin is using RSS, may not work
			include_once (ABSPATH . WPINC . '/rss-functions.php');
			//error_reporting(E_ERROR);
		}


		foreach ($feed_url as $url) {
			//load the structured rss feed(s)
			$rss = fetch_rss($url);
   			$new_fetch = $rss->items;
                
			//the first time through the loop, the array is set up automatically.  For all
			//subsequent trips through the loop (i.e. for additional feeds,) we have to
			//add to the array manually.  array_push($fetch,$old_fetch) just puts the whole
			//$old_fetch object as the last element of the array instead of adding all of the
			//individual elements, which is what we want.
                
			if (count($fetch) != 0) {
            		foreach($new_fetch as $items) {
                  		array_push($fetch,$items);
				}
			}
			else $fetch=$new_fetch;
		}

        
		if($fetch) {

			//sort the items (photos) randomly
			usort($fetch, rand_compare);

            $count = 0;

            	foreach($fetch as $item) {
				//format the title correctly in case the photo title includes text that needs to be escaped
				$item["title"]=htmlspecialchars($item["title"]);

				//use the maximum number of photos to control the foreach loop
				if ($count < $photo_count) {
					//if we haven't displayed the maximum number of photos, build the HTML to display an image including built-in (i.e inline) style elements to center the photo

                    echo '<a href="' . $item["link"] . '" title="' . $item["title"] . '"><img style = "padding: 2px 0px 2px 0px;" src="' . $item["guid"] . '" alt="' . $item["title"] . '" /></a>';  //margin 0 auto iso defining left and righ, style="display: block; margin: 0 auto; padding: 2px 0px 2px 0px; border: 0;"
					echo "\n";
				}
				else break;
				$count = $count + 1;
			}
		}

		//finish sidebar code
		echo '</div>'; //an if statement isn't necessary since we opened a div either way.
		echo $after_widget;
	}	

	//This registers the widget with the Sidebar plugin
	register_sidebar_widget('Photos','disp_sm_feed');

	//This lets the Sidebar plugin know that a built-in control is available
	//350 pixels is a larger height than necessary but IE puts extra spaces between lines so this is the fix for now.
	register_widget_control(array('Photos', 'widgets'), 'widget_photo_sb_control', 600, 350);

}

	/* Function: rand_compare
	** To be used with an array sort function (i.e. usort), this function 
	** will randomly sort an array
	**
	** args: $x=string; $y=string (handled by the function call)
	** returns: a random integer between -1 and 1
	*/

	function rand_compare($xt, $yt) {
 		// We don't care about the array elements passed on so we'll
		// create a random value for the return value
		return mt_rand(-1,1);
	}

	/* Function: widget_photo_sb_control()
	** This is the function that outputs the form to let the users edit
	** the widget's title, the RSS feed and the number of photos to
	** display; mainly minor adjustments from the Google Search widget control
	** args: none
	** returns: nothing
	*/

	function widget_photo_sb_control() {

		// Get our options and see if we're handling a form submission.
		$options = get_option('widget_photo_sb');
		if ( !is_array($options) )
			$options = array('title'=>'Photos', 'feed_url'=>'', 'photo_count'=>'5', 'draw_border'=>FALSE, 'background_color'=>'white', 'padding_top'=>'0', 'padding_right'=>'0', 'padding_bottom'=>'0', 'padding_left'=>'0');
		if ( $_POST['photo_sb-submit'] ) {

			// Remember to sanitize and format use input appropriately.
			$options['title'] = strip_tags(stripslashes($_POST['photo_sb-title']));
			$options['feed_url'] = strip_tags(stripslashes($_POST['photo_sb-feed_url']));
			$options['photo_count'] = strip_tags(stripslashes($_POST['photo_sb-photo_count']));
			$options['draw_border'] = strip_tags(stripslashes($_POST['photo_sb-draw_border']));
			$options['background_color'] = strip_tags(stripslashes($_POST['photo_sb-background_color']));
			$options['padding_top'] = strip_tags(stripslashes($_POST['photo_sb-padding_top']));
			$options['padding_right'] = strip_tags(stripslashes($_POST['photo_sb-padding_right']));
			$options['padding_bottom'] = strip_tags(stripslashes($_POST['photo_sb-padding_bottom']));
			$options['padding_left'] = strip_tags(stripslashes($_POST['photo_sb-padding_left']));

			update_option('widget_photo_sb', $options);
		}

		// Be sure you format your options to be valid HTML attributes.
		$title = htmlspecialchars($options['title'], ENT_QUOTES);
		$feed_url = htmlspecialchars($options['feed_url'], ENT_QUOTES);
		$photo_count = htmlspecialchars($options['photo_count'], ENT_QUOTES);
		$draw_border = $options['draw_border'];
		$background_color = htmlspecialchars($options['background_color'], ENT_QUOTES);
		$padding_top = htmlspecialchars($options['padding_top'], ENT_QUOTES);
		$padding_right = htmlspecialchars($options['padding_right'], ENT_QUOTES);
		$padding_bottom = htmlspecialchars($options['padding_bottom'], ENT_QUOTES);
		$padding_left = htmlspecialchars($options['padding_left'], ENT_QUOTES);
		
		// Here is our little form segment. Notice that we don't need a
		// complete form. This will be embedded into the existing form.

		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-title">' . 'Title:  ' . ' <input style="width: 200px; id="photo_sb-title" name="photo_sb-title" type="text" value="'.$title.'" /></label></p>';
		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-feed_url">' . 'RSS Feed URL\'s (seperate URL\'s with ", "):  ' . '<br/><textarea rows="3" cols="70" id="photo_sb-feed_url" name="photo_sb-feed_url">'.$feed_url.'</textarea></label></p>';

		//create an option box with a set number of values generated by a for loop
		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-photo_count">' . 'Number of photos to show:  ' . '</label><select name="photo_sb-photo_count" id="photo_sb-photo_count" style="width: 50px;">';
		for($list_val=1; $list_val <= 20; $list_val ++) {
			if ($list_val == $photo_count)  
				echo '<option selected>' . $list_val . '</option>';
			
			else 
				echo '<option>' . $list_val . '</option>';
		}
		echo '</select></p>';
		echo '<hr/>';
		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-draw_border">' . 'Include a border for this widget?  ' . '</label><input style="margin-left: 10;" id="photo_sb-draw_border" name="photo_sb-draw_border" type="checkbox" value="1" ';
		echo  $draw_border ? 'checked' : ''; //if the option was selected, make the box checked when the form is open; otherwise leave it unchecked
		echo  '></input></p>';
		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-background_color">' . 'Background color (names or hex codes; e.g. \'white\' or \'#FFFFFF\'):' . ' <input style="width: 70px;" id="photo_sb-background_color" name="photo_sb-background_color" type="text" value="'.$background_color.'" /></label></p>';
		echo '<p style="text-align:left; line-height=1.2em"><label for="photo_sb-padding_top">' . 'Padding:' . '</label><br/>';
		echo '<label for="photo_sb-padding_top">' . 'Top:  ' . '<input style="width: 20px;" id="photo_sb-padding_top" name="photo_sb-padding_top" type="text" value="'.$padding_top.'"/>'
			. '<label for="photo_sb-padding_right">' . '  Right:  ' . '<input style="width: 20px;" id="photo_sb-padding_right" name="photo_sb-padding_right" type="text" value="'.$padding_right.'"/>'
			. '<label for="photo_sb-padding_bottom">' . '  Bottom:  ' . '<input style="width: 20px;" id="photo_sb-padding_bottom" name="photo_sb-padding_bottom" type="text" value="'.$padding_bottom.'"/>'
			. '<label for="photo_sb-padding_left">' . '  Left:  ' . '<input style="width: 20px;" id="photo_sb-padding_left" name="photo_sb-padding_left" type="text" value="'.$padding_left.'"/></p>';
 		echo '<input type="hidden" id="photo_sb-submit" name="photo_sb-submit" value="1" />';
    }

add_action('widgets_init','widget_photo_sb_init');

?>
